use grammatical::*;
use std::error::Error;

mod conlang;
mod datetime;

fn main() -> Result<(), Box<dyn Error>> {
    datetime::print_current_time();
    let args: Vec<_> = std::env::args().skip(1).collect();
    if args.is_empty() {
        for line in std::io::stdin().lines() {
            let line = line?;
            let mut p = Parser::new(&line);
            parse(&mut p);
        }
    }
    for file in args {
        let file = std::fs::read_to_string(file)?;
        let mut p = Parser::new(&file);
        parse(&mut p);
    }
    conlang::print_supplemental();
    Ok(())
}

fn parse(p: &mut Parser) {
    loop {
        match p.rule() {
            Ok(rule) => {
                println!("{rule}");
                continue;
            }
            Err(e) if e.is_end() => {}
            Err(e) => eprintln!("Error {e}"),
        }
        break;
    }
}
